"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _jsCookie = _interopRequireDefault(require("js-cookie"));

var _Snackbar = _interopRequireDefault(require("@material-ui/core/Snackbar"));

var _Button = _interopRequireDefault(require("@material-ui/core/Button"));

var _Dialog = _interopRequireDefault(require("@material-ui/core/Dialog"));

var _DialogActions = _interopRequireDefault(require("@material-ui/core/DialogActions"));

var _DialogContent = _interopRequireDefault(require("@material-ui/core/DialogContent"));

var _DialogContentText = _interopRequireDefault(require("@material-ui/core/DialogContentText"));

var _DialogTitle = _interopRequireDefault(require("@material-ui/core/DialogTitle"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * This component is the MUICookieConsent it pops a Snackbar or a Dialog informing the user about cookie consent.
 */
class MUICookieConsent extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "handleScroll", () => {
      // (top / height) - height * 100
      // const rootNode = document.documentElement;
      // const body = document.body;
      const _document = document,
            body = _document.body,
            rootNode = _document.documentElement;
      const top = "scrollTop";
      const height = "scrollHeight";
      const percentage = (rootNode[top] || body[top]) / ((rootNode[height] || body[height]) - rootNode.clientHeight) * 100;

      if (percentage > this.props.acceptOnScrollPercentage) {
        this.accept();
      }
    });

    _defineProperty(this, "accept", () => {
      const _this$props = this.props,
            cookieName = _this$props.cookieName,
            cookieValue = _this$props.cookieValue,
            expires = _this$props.expires,
            hideOnAccept = _this$props.hideOnAccept,
            onAccept = _this$props.onAccept,
            extraCookieOptions = _this$props.extraCookieOptions; // fire onAccept

      if (onAccept) {
        onAccept();
      } // remove listener if set


      window.removeEventListener("scroll", this.handleScroll);

      _jsCookie.default.set(cookieName, cookieValue, _objectSpread({
        expires
      }, extraCookieOptions));

      if (hideOnAccept) {
        this.setState({
          visible: false
        });
      }
    });

    this.state = {
      visible: false
    };
  }

  componentDidMount() {
    const _this$props2 = this.props,
          cookieName = _this$props2.cookieName,
          debug = _this$props2.debug; // if cookie undefined or debug

    if (_jsCookie.default.get(cookieName) === undefined || debug) {
      this.setState({
        visible: true
      });
    } // if acceptOnScroll is set to true, add a listener


    if (this.props.acceptOnScroll) {
      window.addEventListener("scroll", this.handleScroll, {
        passive: true
      });
    }
  }

  componentWillUnmount() {
    // remove listener if still set
    window.removeEventListener("scroll", this.handleScroll);
  }
  /**
   * checks whether scroll has exceeded set amount and fire accept if so.
   */


  render() {
    const _this$props3 = this.props,
          componentType = _this$props3.componentType,
          children = _this$props3.children,
          message = _this$props3.message,
          snackbarAnchor = _this$props3.snackbarAnchor,
          title = _this$props3.title,
          acceptButtonLabel = _this$props3.acceptButtonLabel;
    const childrenWithProps = React.Children.map(children, child => React.cloneElement(child, {
      onAccept: this.accept
    }));

    if (componentType === "Snackbar") {
      if (!children) {
        return React.createElement(_Snackbar.default, {
          anchorOrigin: snackbarAnchor,
          open: this.state.visible,
          message: React.createElement("span", {
            id: "message-id"
          }, message),
          action: [React.createElement(_Button.default, {
            key: "accept",
            color: "secondary",
            size: "small",
            onClick: this.accept
          }, acceptButtonLabel)]
        });
      }

      return React.createElement(_Snackbar.default, {
        anchorOrigin: snackbarAnchor,
        open: this.state.visible
      }, childrenWithProps);
    }

    if (!children) {
      return React.createElement(_Dialog.default, {
        open: this.state.visible
      }, title ? React.createElement(_DialogTitle.default, null, title) : null, React.createElement(_DialogContent.default, null, React.createElement(_DialogContentText.default, {
        id: "alert-dialog-description"
      }, message)), React.createElement(_DialogActions.default, null, React.createElement(_Button.default, {
        onClick: this.accept,
        color: "secondary"
      }, acceptButtonLabel)));
    }

    return React.createElement(_Dialog.default, {
      open: this.state.visible
    }, childrenWithProps);
  }

}

exports.default = MUICookieConsent;

_defineProperty(MUICookieConsent, "defaultProps", {
  componentType: "Snackbar",
  acceptOnScroll: false,
  acceptOnScrollPercentage: 25,
  expires: 365,
  // default it expires in 365 days
  hideOnAccept: true,
  debug: false,
  extraCookiesOptions: undefined,
  snackbarAnchor: {
    horizontal: "center",
    vertical: "bottom"
  },
  children: null,
  message: "I love cookies!",
  title: null,
  acceptButtonLabel: "Accept"
});